@@ -98,6 +98,7 @@ impl MpScBytesQueue {
             .iter()
             .zip(uninit_slices.iter_mut())
             .for_each(|(bytes, uninit_slice)| {
+                // Every bytes is non-empty, so every io_slice created is non-empty.
                 uninit_slice.write(IoSlice::new(bytes));
             });
 
@@ -168,7 +169,10 @@ pub struct Buffers<'a> {
     io_slice_end: usize,
 }
 
+unsafe impl Send for Buffers<'_> {}
+
 impl Buffers<'_> {
+    /// Return `IoSlice`s that every one of them is non-empty.
     pub fn get_io_slices<'this>(&'this self) -> &[IoSlice<'this>] {
         let pointer = (&**self.io_slices_guard) as *const [MaybeUninit<IoSlice<'this>>];
         let uninit_slices: &[MaybeUninit<IoSlice>] = unsafe { &*pointer };
@@ -208,6 +212,7 @@ impl Buffers<'_> {
 
         let mut bytes_queue_guard = queue.bytes_queue.lock();
 
+        // Every bytes is non-empty, so every io_slice created is non-empty.
         while bufs[0].len() <= n {
             // Update n and shrink bufs
             n -= bufs[0].len();
@@ -254,6 +259,7 @@ mod tests {
         let queue = MpScBytesQueue::new(NonZeroUsize::new(10).unwrap());
 
         for _ in 0..20 {
+            // Test extend
             assert!(queue.get_buffers().is_none());
 
             for i in 0..5 {
@@ -270,6 +276,32 @@ mod tests {
 
             let bytes_slice_inserted = 10;
 
+            {
+                let mut buffers = queue.get_buffers().unwrap();
+                assert_eq!(buffers.get_io_slices().len(), bytes_slice_inserted);
+                for io_slice in buffers.get_io_slices() {
+                    assert_eq!(&**io_slice, &*bytes);
+                }
+
+                assert!(!buffers
+                    .advance(NonZeroUsize::new(bytes_slice_inserted * bytes.len()).unwrap()));
+                assert!(!buffers.advance(NonZeroUsize::new(100).unwrap()));
+            }
+
+            // Test push
+            assert!(queue.get_buffers().is_none());
+
+            for i in 0..10 {
+                eprintln!("Pushing (success) {}", i);
+                queue.push(bytes.clone());
+
+                assert_eq!(queue.get_buffers().unwrap().get_io_slices().len(), i + 1);
+            }
+
+            eprintln!("Test get_buffers");
+
+            let bytes_slice_inserted = 10;
+
             let mut buffers = queue.get_buffers().unwrap();
             assert_eq!(buffers.get_io_slices().len(), bytes_slice_inserted);
             for io_slice in buffers.get_io_slices() {
